@@ -631,16 +631,21 @@ UBX_CONFIG_DATABASE = {
     # CFG_SIGNAL Satellite systems (GNSS) signal configuration
     "CFG_SIGNAL_GPS_ENA": (0x1031001F, L),
     "CFG_SIGNAL_GPS_L1CA_ENA": (0x10310001, L),
+    "CFG_SIGNAL_GPS_L2C_ENA": (0x10310003, L),
     "CFG_SIGNAL_SBAS_ENA": (0x10310020, L),
     "CFG_SIGNAL_SBAS_L1CA_ENA": (0x10310005, L),
     "CFG_SIGNAL_GAL_ENA": (0x10310021, L),
     "CFG_SIGNAL_GAL_E1_ENA": (0x10310007, L),
+    "CFG_SIGNAL_GAL_E5B_ENA": (0x1031000A, L),
     "CFG_SIGNAL_BDS_ENA": (0x10310022, L),
     "CFG_SIGNAL_BDS_B1_ENA": (0x1031000D, L),
+    "CFG_SIGNAL_BDS_B2_ENA": (0x1031000E, L),
     "CFG_SIGNAL_QZSS_ENA": (0x10310024, L),
     "CFG_SIGNAL_QZSS_L1CA_ENA": (0x10310012, L),
+    "CFG_SIGNAL_QZSS_L2C_ENA": (0x10310015, L),
     "CFG_SIGNAL_GLO_ENA": (0x10310025, L),
     "CFG_SIGNAL_GLO_L1_ENA": (0x10310018, L),
+    "CFG_SIGNAL_GLO_L2_ENA": (0x1031001A, L),
     # CFG_SPI Configuration of the SPI interface
     "CFG_SPI_MAXFF": (0x20640001, U1),
     "CFG_SPI_CPOLARITY": (0x10640002, L),
