@@ -42,6 +42,7 @@ from pyubx2.ubxtypes_core import (
     U4,
     U5,
     U6,
+    U7,
     U8,
     U9,
     U12,
@@ -184,6 +185,45 @@ UBX_PAYLOADS_GET = {
         ),
     },
     "CFG-DYNSEED": {"version": U1, "reserved1": U3, "seedHi": U4, "seedLo": U4},
+    "CFG-ESFALG": {
+        "bitfield": U4,
+        "yaw": U4,
+        "pitch": I2,
+        "roll": I2,
+    },
+    "CFG-ESFA": {
+        "version": U1,
+        "reserved1": U9,
+        "accelRmsThdl": U1,
+        "frequency": U1,
+        "latency": U2,
+        "accuracy": U2,
+        "reserved2": U4,
+    },
+    "CFG-ESFG": {
+        "version": U1,
+        "reserved1": U7,
+        "tcTableSaveRate": U2,
+        "gyroRmsThdl": U1,
+        "frequency": U1,
+        "latency": U2,
+        "accuracy": U2,
+        "reserved2": U4,
+    },
+    "CFG-ESFWT": {
+        "version": U1,
+        "flags1": X1,
+        "flags2": X1,
+        "reserved1": U1,
+        "wtFactor": U4,
+        "wtQuantError": U4,
+        "wtCountMax": U4,
+        "wtLatency": U2,
+        "wtFrequency": U1,
+        "flags3": X1,
+        "speedDeadBand": U2,
+        "reserved2": U1,
+    },
     "CFG-ESRC": {
         "version": U1,
         "numSources": U1,
@@ -243,6 +283,10 @@ UBX_PAYLOADS_GET = {
             },
         ),
     },
+    "CFG-HNR": {
+        "highNavRate": U1,
+        "reserved1": U3,
+    },
     "CFG-INF": {
         "protocolID": U1,
         "reserved1": U3,
@@ -408,6 +452,16 @@ UBX_PAYLOADS_GET = {
         "scanmode2": X1,
         "scanmode1": X4,
     },
+    "CFG-SENIF": {
+        "type": U1,
+        "version": U1,
+        "flags": X1,
+        "pioConf": X2,
+    },
+    "CFG-SLAS": {
+        "mode": X1,
+        "reserved1": U3,
+    },
     "CFG-SMGR": {
         "minGNSSFix": U1,
         "maxFreqChange": U2,
@@ -604,6 +658,7 @@ UBX_PAYLOADS_GET = {
         "second": U1,
         "valid": X1,
         "nano": I4,
+        "gpsFix": U1,
         "flags": X1,
         "reserved1": U2,
         "lon": I4,
